==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QByteArray_FromBase64Result_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qbytearray.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QByteArray_FromBase64Result(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QByteArray::FromBase64Result")
    QByteArray::FromBase64Result *_ptr = reinterpret_cast<QByteArray::FromBase64Result *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QByteArray_FromBase64Result_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QByteArray::FromBase64Result *__qt_this = new(__qtjambi_ptr) QByteArray::FromBase64Result();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QByteArray::FromBase64Result
void __qt_destruct_QByteArray_FromBase64Result(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QByteArray::FromBase64Result")
    reinterpret_cast<QByteArray::FromBase64Result*>(ptr)->~FromBase64Result();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QByteArray::FromBase64Result::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_initialize_1native__Lio_qt_core_QByteArray_00024FromBase64Result_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArray::FromBase64Result::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArray_FromBase64Result_0, sizeof(QByteArray::FromBase64Result), typeid(QByteArray::FromBase64Result), false, &deleter_QByteArray_FromBase64Result, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QByteArray::FromBase64Result::operator bool()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_isOk_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArray::FromBase64Result::operator bool()const", __qt_this)
        __java_return_value = __qt_this->operator bool();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArray::FromBase64Result::operator==(QByteArray::FromBase64Result,QByteArray::FromBase64Result)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_equals_1native_1cref_1QByteArray_1FromBase64Result__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArray::FromBase64Result::operator==(QByteArray::FromBase64Result,QByteArray::FromBase64Result)", __qt_this)
        const QByteArray::FromBase64Result& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QByteArray::FromBase64Result>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArray::FromBase64Result::swap(QByteArray::FromBase64Result&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_swap_1native_1ref_1QByteArray_1FromBase64Result__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArray::FromBase64Result::swap(QByteArray::FromBase64Result&)", __qt_this)
        QByteArray::FromBase64Result& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QByteArray::FromBase64Result>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_setDecoded_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID decoded0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QByteArray& __qt_decoded0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(decoded0);
        __qt_this->decoded = __qt_decoded0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_decoded_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QByteArray&  __qt_value = __qt_this->decoded;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_setDecodingStatus_1native_1cref_1QByteArray_1Base64DecodingStatus__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint decodingStatus0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QByteArray::Base64DecodingStatus __qt_decodingStatus0 = qtjambi_cast<QByteArray::Base64DecodingStatus>(__jni_env, decodingStatus0);
        __qt_this->decodingStatus = QByteArray::Base64DecodingStatus(__qt_decodingStatus0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_decodingStatus_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QByteArray::Base64DecodingStatus&  __qt_value = __qt_this->decodingStatus;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QByteArray_FromBase64Result(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QByteArray::FromBase64Result>("QByteArray::FromBase64Result", "io/qt/core/QByteArray$FromBase64Result");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QByteArray_FromBase64Result, {
        ConstructorInfo(&__qt_construct_QByteArray_FromBase64Result_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QByteArray_FromBase64Result);
    registerMetaType<QByteArray::FromBase64Result>("QByteArray::FromBase64Result");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QByteArray_FromBase64Result_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qbytearray.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QByteArray_FromBase64Result(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QByteArray::FromBase64Result")
    QByteArray::FromBase64Result *_ptr = reinterpret_cast<QByteArray::FromBase64Result *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new FromBase64Result()
void __qt_construct_QByteArray_FromBase64Result(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FromBase64Result()")
    Q_UNUSED(__java_arguments)
    QByteArray::FromBase64Result *__qt_this = new(__qtjambi_ptr) QByteArray::FromBase64Result();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QByteArray::FromBase64Result::FromBase64Result()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_initialize_1native__Lio_qt_core_QByteArray_00024FromBase64Result_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArray::FromBase64Result::FromBase64Result()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArray_FromBase64Result, sizeof(QByteArray::FromBase64Result), typeid(QByteArray::FromBase64Result), false, &deleter_QByteArray_FromBase64Result, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new FromBase64Result(QByteArray::FromBase64Result)
void __qt_construct_QByteArray_FromBase64Result_cref_QByteArray_FromBase64Result(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FromBase64Result(QByteArray::FromBase64Result)")
    jobject other0 = __java_arguments[0].l;
    const QByteArray::FromBase64Result& __qt_other0 = qtjambi_cast<const QByteArray::FromBase64Result& >(__jni_env, other0);
    QByteArray::FromBase64Result *__qt_this = new(__qtjambi_ptr) QByteArray::FromBase64Result(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QByteArray::FromBase64Result::FromBase64Result(QByteArray::FromBase64Result)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_initialize_1native__Lio_qt_core_QByteArray_00024FromBase64Result_2Lio_qt_core_QByteArray_00024FromBase64Result_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArray::FromBase64Result::FromBase64Result(QByteArray::FromBase64Result)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArray_FromBase64Result_cref_QByteArray_FromBase64Result, sizeof(QByteArray::FromBase64Result), typeid(QByteArray::FromBase64Result), false, &deleter_QByteArray_FromBase64Result, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new FromBase64Result{QByteArray,QByteArray::Base64DecodingStatus}
void __qt_construct_QByteArray_FromBase64Result_QByteArray_QByteArray_Base64DecodingStatus(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct FromBase64Result{QByteArray,QByteArray::Base64DecodingStatus}")
    jobject decoded0 = __java_arguments[0].l;
    QByteArray __qt_decoded0 = qtjambi_cast<QByteArray >(__jni_env, decoded0);
    jobject decodingStatus1 = __java_arguments[1].l;
    QByteArray::Base64DecodingStatus __qt_decodingStatus1 = qtjambi_cast<QByteArray::Base64DecodingStatus>(__jni_env, decodingStatus1);
    QByteArray::FromBase64Result *__qt_this = new(__qtjambi_ptr) QByteArray::FromBase64Result{__qt_decoded0, QByteArray::Base64DecodingStatus(__qt_decodingStatus1)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QByteArray::FromBase64Result::FromBase64Result{QByteArray,QByteArray::Base64DecodingStatus}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_initialize_1native__Lio_qt_core_QByteArray_00024FromBase64Result_2Lio_qt_core_QByteArray_2Lio_qt_core_QByteArray_00024Base64DecodingStatus_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject decoded0,
 jobject decodingStatus1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QByteArray::FromBase64Result::FromBase64Result{QByteArray,QByteArray::Base64DecodingStatus}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = decoded0;
        arguments[1].l = decodingStatus1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QByteArray_FromBase64Result_QByteArray_QByteArray_Base64DecodingStatus, sizeof(QByteArray::FromBase64Result), typeid(QByteArray::FromBase64Result), false, &deleter_QByteArray_FromBase64Result, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QByteArray::FromBase64Result
void __qt_destruct_QByteArray_FromBase64Result(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QByteArray::FromBase64Result")
    reinterpret_cast<QByteArray::FromBase64Result*>(ptr)->~FromBase64Result();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QByteArray::FromBase64Result::operator bool()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_isOk_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArray::FromBase64Result::operator bool()const", __qt_this)
        __java_return_value = __qt_this->operator bool();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArray::FromBase64Result::operator==(QByteArray::FromBase64Result,QByteArray::FromBase64Result)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_equals_1native_1cref_1QByteArray_1FromBase64Result__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArray::FromBase64Result::operator==(QByteArray::FromBase64Result,QByteArray::FromBase64Result)", __qt_this)
        const QByteArray::FromBase64Result& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QByteArray::FromBase64Result>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QByteArray::FromBase64Result::swap(QByteArray::FromBase64Result&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_swap_1native_1ref_1QByteArray_1FromBase64Result__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QByteArray::FromBase64Result::swap(QByteArray::FromBase64Result&)", __qt_this)
        QByteArray::FromBase64Result& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QByteArray::FromBase64Result>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_setDecoded_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID decoded0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QByteArray& __qt_decoded0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(decoded0);
        __qt_this->decoded = __qt_decoded0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_decoded_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QByteArray&  __qt_value = __qt_this->decoded;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_setDecodingStatus_1native_1cref_1QByteArray_1Base64DecodingStatus__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint decodingStatus0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QByteArray::Base64DecodingStatus __qt_decodingStatus0 = qtjambi_cast<QByteArray::Base64DecodingStatus>(__jni_env, decodingStatus0);
        __qt_this->decodingStatus = QByteArray::Base64DecodingStatus(__qt_decodingStatus0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_decodingStatus_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QByteArray::Base64DecodingStatus&  __qt_value = __qt_this->decodingStatus;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QByteArray_00024FromBase64Result_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QByteArray::FromBase64Result *__qt_this = QtJambiAPI::objectFromNativeId<QByteArray::FromBase64Result>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QByteArray_FromBase64Result(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QByteArray::FromBase64Result>("QByteArray::FromBase64Result", "io/qt/core/QByteArray$FromBase64Result");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QByteArray_FromBase64Result, {
        ConstructorInfo(&__qt_construct_QByteArray_FromBase64Result, nullptr)
       ,ConstructorInfo(&__qt_construct_QByteArray_FromBase64Result_cref_QByteArray_FromBase64Result, "Lio/qt/core/QByteArray$FromBase64Result;")
       ,ConstructorInfo(&__qt_construct_QByteArray_FromBase64Result_QByteArray_QByteArray_Base64DecodingStatus, "Lio/qt/core/QByteArray;Lio/qt/core/QByteArray$Base64DecodingStatus;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QByteArray_FromBase64Result);
    registerMetaType<QByteArray::FromBase64Result>("QByteArray::FromBase64Result");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
